=== modified file 'charmhelpers/contrib/storage/linux/ceph.py'
--- charmhelpers/contrib/storage/linux/ceph.py	2017-06-09 15:06:01 +0000
+++ charmhelpers/contrib/storage/linux/ceph.py	2017-07-20 13:30:54 +0000
@@ -1372,7 +1372,7 @@
             return {}
 
         conf = config_flags_parser(conf)
-        if type(conf) != dict:
+        if not isinstance(conf, dict):
             log("Provided config-flags is not a dictionary - ignoring",
                 level=WARNING)
             return {}

=== modified file 'charmhelpers/fetch/snap.py'
--- charmhelpers/fetch/snap.py	2017-06-16 23:07:35 +0000
+++ charmhelpers/fetch/snap.py	2017-07-20 13:30:54 +0000
@@ -18,13 +18,15 @@
 https://lists.ubuntu.com/archives/snapcraft/2016-September/001114.html
 """
 import subprocess
-from os import environ
+import os
 from time import sleep
 from charmhelpers.core.hookenv import log
 
 __author__ = 'Joseph Borg <joseph.borg@canonical.com>'
 
-SNAP_NO_LOCK = 1  # The return code for "couldn't acquire lock" in Snap (hopefully this will be improved).
+# The return code for "couldn't acquire lock" in Snap
+# (hopefully this will be improved).
+SNAP_NO_LOCK = 1
 SNAP_NO_LOCK_RETRY_DELAY = 10  # Wait X seconds between Snap lock checks.
 SNAP_NO_LOCK_RETRY_COUNT = 30  # Retry to acquire the lock X times.
 SNAP_CHANNELS = [
@@ -53,13 +55,17 @@
 
     while return_code is None or return_code == SNAP_NO_LOCK:
         try:
-            return_code = subprocess.check_call(['snap'] + commands, env=environ)
+            return_code = subprocess.check_call(['snap'] + commands,
+                                                env=os.environ)
         except subprocess.CalledProcessError as e:
             retry_count += + 1
             if retry_count > SNAP_NO_LOCK_RETRY_COUNT:
-                raise CouldNotAcquireLockException('Could not aquire lock after %s attempts' % SNAP_NO_LOCK_RETRY_COUNT)
+                raise CouldNotAcquireLockException(
+                    'Could not aquire lock after {} attempts'
+                    .format(SNAP_NO_LOCK_RETRY_COUNT))
             return_code = e.returncode
-            log('Snap failed to acquire lock, trying again in %s seconds.' % SNAP_NO_LOCK_RETRY_DELAY, level='WARN')
+            log('Snap failed to acquire lock, trying again in {} seconds.'
+                .format(SNAP_NO_LOCK_RETRY_DELAY, level='WARN'))
             sleep(SNAP_NO_LOCK_RETRY_DELAY)
 
     return return_code

=== modified file 'tests/contrib/openstack/test_openstack_utils.py'
--- tests/contrib/openstack/test_openstack_utils.py	2017-06-16 23:07:35 +0000
+++ tests/contrib/openstack/test_openstack_utils.py	2017-07-20 13:30:54 +0000
@@ -1946,11 +1946,9 @@
         snaps = ['os_project']
         mode = 'jailmode'
         src = 'snap:beta-xenial-ocata'
-        post_install = MagicMock()
-
         openstack.install_os_snaps(
             openstack.get_snaps_install_info_from_origin(
-                    snaps, src, mode=mode))
+                snaps, src, mode=mode))
         mock_snap_install.assert_called_with(
             'os_project', '--beta', '--jailmode')
 

